<div align="center">
    <img src="../../docs/images/logo-title.png" height="80px">
    <h3>The Graph Of LIfe Library.</h3>
</div>


## What is in this folder? 

code for different PyG GNN layers and graph transformer layers for this library

- ✅ `pna_pyg.py`: `PNAMessagePassingPyg` class implements the PNA layer, good example script for new GNN layers
- ✅ `gps_pyg.py`: `GPSLayerPyg` class is the implementation of the graphGPS layer in PyG, a graph transformer layer
- `gated_gcn_pyg.py`: `GatedGCNPyg` class for the gated GCN layer implementation. 
- `gin_pyg.py`: GIN and GINE layer implementation in the `GINConvPyg` and `GINEConvPyg` class respectively
- `mpnn_pyg.py`: `MPNNPlusPyg` class implements the MPNN layer
- `pooling_pyg.py`: pooling layers in pyg
